@@ -503,7 +503,8 @@ class ActiveResource(object):
             A list of ActiveResource objects.
         """
         resources = []
-        for element in elements:
+        # slice elements to ensure that this is a list-type object not a dict
+        for element in elements[:]:
             resources.append(cls(element, prefix_options))
         return resources
 
@@ -679,21 +680,6 @@ class ActiveResource(object):
         options = dict([(k, options.get(k, '')) for k in keys])
         return template.safe_substitute(options)
 
-    @classmethod
-    def _scrub_name(cls, name):
-        """Remove invalid characters from attribute names.
-
-        Args:
-            name: the string to scrub
-        Returns:
-            The part of the string that is a valid name, or None if unscrubbable
-        """
-        name = name.lower().replace('-', '_')
-        match = VALID_NAME.search(name)
-        if match:
-            return match.group(0)
-        return None
-
     # Public instance methods
     def to_dict(self):
         """Convert the object to a dictionary."""
@@ -831,7 +817,8 @@ class ActiveResource(object):
             else:
                 # Add/update an attribute
                 self.attributes[name] = value
-        object.__setattr__(self, name, value)
+        else:
+            object.__setattr__(self, name, value)
 
     def __repr__(self):
         return '%s(%s)' % (self._singular, self.id)
@@ -863,7 +850,6 @@ class ActiveResource(object):
                 attr = value
             # Store the actual value in the attributes dictionary
             self.attributes[key] = attr
-            attr_name = self._scrub_name(key)
 
     def _find_class_for(self, element_name=None, class_name=None):
         """Look in the parent modules for classes matching the element name.
